@@ -117,11 +117,15 @@ class ZipArchive implements Countable
      * @cvalue ZIP_FL_UNCHANGED
      */
     public const FL_UNCHANGED = UNKNOWN;
+/* deprecated in libzip 1.10.0 */
+#ifdef ZIP_FL_RECOMPRESS
     /**
      * @var int
      * @cvalue ZIP_FL_RECOMPRESS
+     * @deprecated
      */
     public const FL_RECOMPRESS = UNKNOWN;
+#endif
     /**
      * @var int
      * @cvalue ZIP_FL_ENCRYPTED
@@ -171,6 +175,13 @@ class ZipArchive implements Countable
      */
     public const FL_ENC_CP437 = UNKNOWN;
 
+    /**
+     * Additionnal flags not from libzip
+     * @var int
+     * @cvalue ZIP_FL_OPEN_FILE_NOW
+     */
+    public const FL_OPEN_FILE_NOW = UNKNOWN;
+
     /**
      * @var int
      * @cvalue ZIP_CM_DEFAULT
